summaryrefslogtreecommitdiffstats
path: root/libk9copy/processList.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libk9copy/processList.cpp')
-rw-r--r--libk9copy/processList.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/libk9copy/processList.cpp b/libk9copy/processList.cpp
index c95df4f..35551c1 100644
--- a/libk9copy/processList.cpp
+++ b/libk9copy/processList.cpp
@@ -19,11 +19,11 @@
#include "kpushbutton.h"
/*
* Constructs a processList as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
-processList::processList( TQWidget* tqparent, const char* name, WFlags fl )
- : TQWidget( tqparent, name, fl )
+processList::processList( TQWidget* parent, const char* name, WFlags fl )
+ : TQWidget( parent, name, fl )
{
if ( !name )
setName( "processList" );
@@ -19,11 +19,11 @@
#include "kpushbutton.h"
/*
- * Constructs a processList as a child of 'tqparent', with the
+ * Constructs a processList as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/